@@ -40,6 +40,7 @@
 #include "gui.h"
 #include "midi.h"
 #include "pipeline.h"
+#include "subprocess.h"
 #include "v4l2util.h"
 
 namespace po = boost::program_options;
@@ -109,6 +110,14 @@ void Application::set_current_clip_number(unsigned int clipnumber)
     if (config_->get_verbose())
         std::cout << "current clip is " << selected_clip_ << std::endl;
 }
+
+static void check_for_mencoder()
+{
+    std::string command("mencoder -list-options");
+    bool ret = subprocess::run_command(command);
+    if (! ret)
+        g_critical("Could not find mencoder\n");
+}
 /**
  * Parses the command line and runs the application.
  */
@@ -116,8 +125,7 @@ void Application::run(int argc, char *argv[])
 {
     std::string video_source = "/dev/video0";
     std::string project_home = DEFAULT_PROJECT_HOME;
-    po::options_description desc("Toonloop live animation editor");
-    // std::cout << "adding options" << std::endl;
+    po::options_description desc("Options");
     desc.add_options()
         ("help,h", "Show this help message and exit")
         ("project-home,H", po::value<std::string>()->default_value(project_home), "Path to the saved files")
@@ -154,10 +162,16 @@ void Application::run(int argc, char *argv[])
     
     po::store(po::parse_command_line(argc, argv, desc), options);
     po::notify(options);
+
+    // tmp: 
+    bool verbose = options["verbose"].as<bool>();
     // Options that makes the program exit:
     if (options.count("help"))
     {
+        // TODO: also print clutter-gst command line help
         std::cout << desc << std::endl;
+        //std::cout << INTERACTIVE_HELP << std::endl;
+        //std::cout << std::endl;
         return;
     }
     if (options.count("version"))
@@ -191,14 +205,16 @@ void Application::run(int argc, char *argv[])
                 // exit(1); // exit with error
             }
         }
-        std::cout << "video-source is set to " << video_source << std::endl;
+        if (verbose)
+            std::cout << "video-source is set to " << video_source << std::endl;
     }
     if (options.count("project-home")) // of course it will be there.
     {
         project_home = options["project-home"].as<std::string>();
         if (project_home == DEFAULT_PROJECT_HOME) // FIXME: replace ~ by $HOME instead of hard-coding this
             project_home = std::string(std::getenv("HOME")) + "/Documents/toonloop/default";
-        std::cout << "project-home is set to " << project_home << std::endl;
+        if (verbose)
+            std::cout << "project-home is set to " << project_home << std::endl;
         if (! setup_project_home(project_home))
             exit(1);
 
@@ -211,7 +227,8 @@ void Application::run(int argc, char *argv[])
     if (options.count("intervalometer-interval"))
         std::cout << "The rate of the intervalometer is set to " << options["intervalometer-interval"].as<double>() << std::endl; 
 #endif
-    std::cout << "The initial frame rate for clip playhead is set to " << options["playhead-fps"].as<int>() << std::endl;
+    if (verbose)
+        std::cout << "The initial frame rate for clip playhead is set to " << options["playhead-fps"].as<int>() << std::endl;
     if (options.count("playhead-fps"))
     { 
         for (ClipIterator iter = clips_.begin(); iter != clips_.end(); ++iter)
@@ -220,8 +237,8 @@ void Application::run(int argc, char *argv[])
 
     if (options["fullscreen"].as<bool>())
     {
-        std::cout << "Fullscreen mode is on: " << std::endl;
-        std::cout << "Fullscreen mode is on: " << options["fullscreen"].as<bool>() << std::endl;
+        if (verbose)
+            std::cout << "Fullscreen mode is on: " << options["fullscreen"].as<bool>() << std::endl;
     }
     
     // Stores the options in the Configuration class.
@@ -234,8 +251,6 @@ void Application::run(int argc, char *argv[])
     update_project_home_for_each_clip();
     config_->set_video_source(video_source);
     
-    
-
     // Start OSC
     if (config_->get_osc_recv_port() != OSC_PORT_NONE)
     {
@@ -258,9 +273,14 @@ void Application::run(int argc, char *argv[])
                 // Don't exit
             }
         }
-        std::cout << "Starting OSC receiver." << std::endl;
-    } else
-        std::cout << "OSC receiver is disabled" << std::endl;
+        if (verbose)
+            std::cout << "Starting OSC receiver." << std::endl;
+    } 
+    else 
+    {
+        if (verbose)
+            std::cout << "OSC receiver is disabled" << std::endl;
+    }
     if (config_->get_osc_send_port() != OSC_PORT_NONE)
     {
         //TODO:2010-08-26:aalex:Replace atoi by something more sturdy
@@ -276,8 +296,12 @@ void Application::run(int argc, char *argv[])
             std::cerr << "Sending port number " << config_->get_osc_send_port() <<  "is over the maximum of 65535." <<  std::endl;
             exit(1);
         }
-    } else
-        std::cout << "OSC sender is disabled" << std::endl;
+    } 
+    else 
+    {
+        if (verbose)
+            std::cout << "OSC sender is disabled" << std::endl;
+    }
     osc_.reset(new OscInterface(this, config_->get_osc_recv_port(), config_->get_osc_send_port(), config_->get_osc_send_addr()));
     if (config_->get_osc_recv_port() != OSC_PORT_NONE || config_->get_osc_send_port() != OSC_PORT_NONE)
     {
@@ -295,15 +319,18 @@ void Application::run(int argc, char *argv[])
         g_error("Unable to initialize Clutter: %s", error->message);
     clutter_gst_init(&argc, &argv);
     // start GUI
-    std::cout << "Starting GUI." << std::endl;
+    if (verbose)
+        std::cout << "Starting GUI." << std::endl;
     gui_.reset(new Gui(this));
     // start Pipeline
-    std::cout << "Starting pipeline." << std::endl;
+    if (verbose)
+        std::cout << "Starting pipeline." << std::endl;
     pipeline_.reset(new Pipeline(this));
     // Start MIDI
     // std::cout << "Starting MIDI input." << std::endl;
     midi_input_.reset(new MidiInput(this));
-    midi_input_->enumerate_devices();
+    if (verbose)
+        midi_input_->enumerate_devices();
     if (config_->get_midi_input_number() != MIDI_INPUT_NONE)
     {
         bool midi_ok = midi_input_->open(config_->get_midi_input_number());
@@ -328,7 +355,11 @@ void Application::run(int argc, char *argv[])
     else
         std::cout << "There is no layout number " << layout << ". Using 0." << std::endl;
     // Run the main loop
-    std::cout << "Running toonloop" << std::endl;
+    if (verbose)
+        std::cout << "Running toonloop" << std::endl;
+    // This call is blocking:
+    check_for_mencoder();
+    // Starts it all:
     gtk_main();
 }
 /**
@@ -399,7 +430,8 @@ OscInterface* Application::get_osc_interface()
 
 void Application::quit()
 {
-    std::cout << "Quitting the application." << std::endl;
+    if (config_->get_verbose())
+        std::cout << "Quitting the application." << std::endl;
     pipeline_->stop();
     gtk_main_quit();
 }
